#
# spec file for package yast2-services-manager
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change spec file in build service directly
#            Use https://github.com/yast/yast-services-manager repo
#
######################################################################

Name:           yast2-services-manager
Version:        3.2.2
Release:        2.3.1
BuildArch:      noarch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2

Requires:       ruby
# ServicesManager library
Requires:       yast2 >= 3.2.37.2
Requires:       yast2-ruby-bindings >= 1.2.0
# need new enough installation for its inst clients
Conflicts:      yast2-installation < 3.1.32

Obsoletes:      yast2-runlevel
Conflicts:      yast2-runlevel

BuildRequires:  ruby
BuildRequires:  update-desktop-files
BuildRequires:  yast2-ruby-bindings >= 1.2.0
# ServicesManager library
BuildRequires:  yast2 >= 3.2.37.2
# Support for 'data' directory in rake install task
BuildRequires:  rubygem(rspec)
BuildRequires:  rubygem(yast-rake) >= 0.1.7

Summary:        YaST2 - Services Manager
License:        GPL-2.0+
Group:          System/YaST
Url:            https://github.com/yast/yast-services-manager

%description
Provides user interface and libraries to configure systemd
services and targets.

%prep
%setup -n %{name}-%{version}

%build

%check
# opensuse-13.1 does not contain rspec in default repositories
%if 0%{?suse_version} > 1310
rake test:unit
%endif

%install
rake install DESTDIR="%{buildroot}"
%suse_update_desktop_file services-manager

%define yast_dir %{_prefix}/share/YaST2

%files
%defattr(-,root,root)
%{yast_dir}/clients/*.rb
%{yast_dir}/modules/*.rb
%{yast_dir}/schema/autoyast/rnc/*.rnc
%dir %{yast_dir}/lib/services-manager/
%dir %{yast_dir}/lib/services-manager/clients
%{yast_dir}/lib/services-manager/*.rb
%{yast_dir}/lib/services-manager/clients/*.rb
%dir %{yast_dir}/data/services-manager/
%{yast_dir}/data/services-manager/*.erb
%{_prefix}/share/applications/YaST2/services-manager.desktop

%dir %_docdir/
%_docdir/%name/
%_docdir/%name/COPYING

%changelog
* Wed Aug 30 2017 mvidner@suse.com
- Use fewer calls of systemctl to speed up startup (bsc#1045658)
- 3.2.2
* Tue Feb 14 2017 schubi@suse.de
- Added lib/services-manager/clients/*.rb to spec file
  (FATE#321738).
* Mon Feb 13 2017 schubi@suse.de
- AutoYaST: "Write" can be called in first and second installation
  stage (FATE#321738).
- 3.2.1
* Thu Jan 19 2017 schubi@suse.de
- Using systemctl calls (is-active, is-enabled) to evaluate if the
  service is enabled/active (bnc#1017166, bnc#1012047)
- AY-Import: Filter out all YaST services which should e.g. not be
  restarted while installation.(bnc#956043)
- 3.2.0
* Tue Nov 15 2016 igonzalezsosa@suse.com
- Use the X-SuSE-YaST-AutoInstResourceAliases key to get rid
  of the runlevel.desktop file (related to bsc#887115 and
  bsc#1008301)
- 3.1.43
* Wed Jan 13 2016 igonzalezsosa@suse.com
- Add X-SuSE-YaST-AutoInstSchema declaration so
  services-manager.rnc could be included in yast2-schema package
- Fix validation of AutoYaST profile (bsc#954412)
- 3.1.42
* Wed Nov 25 2015 crojasaragonez@hotmail.com
- Closing window with x icon fixed (bsc#956917)
- 3.1.41
* Mon Nov 23 2015 locilka@suse.com
- Service state 'activating' is considered to be 'active',
  'deactivating' is 'inactive' and 'reloading' is 'active'.
  This fixes the second stage of AutoYaST installation getting hung
  in certain cases as it tried to restart itself (bsc#956043).
- 3.1.40
* Fri Dec 19 2014 schubi@suse.de
- AutoYaST: Moved code from autoyast2 package to import function of
  services_manager_target. (bnc#909745)
- 3.1.39
* Wed Dec 17 2014 schubi@suse.de
- AutoYaST import: initialize Yast::I18n correctly
  (bnc#909768)
- 3.1.38
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Wed Dec  3 2014 locilka@suse.com
- Fixed adjusting service state according to new settings, already
  loaded services were ignored (bnc#906730)
- 3.1.37
* Mon Nov 17 2014 ancor@suse.com
- From SLE12 maintenance: fixed installation to use the
  localized version of the default target name (bnc#895023).
- 3.1.36
* Tue Nov  4 2014 jreidinger@suse.com
- Do not overwrite predefined target value in live installer
  (bnc#891213)
- 3.1.35
* Tue Oct 14 2014 cwh@suse.com
- Added minimal commandline support: just 'help' (bnc#893622)
- 3.1.34
* Fri Sep 19 2014 locilka@suse.com
- Defining safe minimal width of the Default Target UI entry
  (bnc#897443)
- 3.1.33
* Fri Sep 19 2014 locilka@suse.com
- Defining textdomain in ServicesManagerTarget::BaseTargets module
  (bnc#892366)
- 3.1.32
* Thu Sep  4 2014 mvidner@suse.com
- Use a more flexible rubygem requirement syntax (bnc#895069)
- 3.1.31
* Mon Aug 25 2014 schubi@suse.de
- Autoyast: Moved minimal configuration to a central place in
  inst_finish. (bnc#886464)
- 3.1.30
* Tue Aug 19 2014 locilka@suse.com
- Targets marked for translations, adjusting UI in a way that even
  longer targets (translations) fit into it (bnc#892366)
- 3.1.29
* Mon Jul 28 2014 schubi@suse.de
- Do not set default target while autoyast installation/update.
  (bnc#889055)
- 3.1.28
* Fri Jul 25 2014 ancor@suse.com
- Ensures that the errors list is cleared if the user decides to
  continue after a failure (by delegating ServiceManager.errors to
  ServiceManagerService)
- Fixes bnc#888555
- 3.1.27
* Thu Jul 24 2014 locilka@suse.com
- While saving services state (activate/deactivate), do not touch
  a service, that is already in the desired state (bnc#884756)
- 3.1.26
* Wed Jul 23 2014 locilka@suse.com
- Showing info that Services Manager hasn't been configured yet in
  AutoYast till it's cloned from the system or user enters
  the module and saves its configuration (bnc#887694)
- 3.1.25
* Tue Jul 22 2014 locilka@suse.com
- Using new library ServicesProposal, that holds information about
  enabled/disabled services during installation, for exporting the
  services configuration for AutoYast at the end of installation
  (bnc#887688)
- 3.1.24
* Tue Jul 22 2014 locilka@suse.com
- Services Manager client for AutoYast marked as clonable (meaning:
  can read the current system state) (bnc#887115)
- 3.1.23
* Thu Jul 17 2014 locilka@suse.com
- Fixed AutoYast summary to show both enabled and disabled services
- Fixed reading targets - now they read in all cases except the
  initial installation where systemctl doesn't work in chroot
- Fixed AutoYast schema to allow service or listentry as AutoYast
  by default exports all single entries as 'listentry'
- All bnc#887695 and bnc#887115
- 3.1.22
* Mon Jul 14 2014 locilka@suse.com
- ServicesManagerServiceClass and ServicesManagerTargetClass
  switched to using lazy loading of system(ctl) data
- Fixed Export AutoYast functionality to return the currently
  supported and documented format
- Added tests for all the other AutoYast formats supported
  for Import (all bnc#885800)
- 3.1.21
* Tue Jul  8 2014 locilka@suse.com
- Function 'localize' moved to ServicesManagerTarget library and
  added a test case (bnc#886117)
- 3.1.20
* Mon Jul  7 2014 locilka@suse.com
- Fixed broken N_(...) call (bnc#886040)
- 3.1.19
* Fri Jul  4 2014 locilka@suse.com
- Default systemd target names marked for translation (bnc#884339)
- 3.1.18
* Thu Jul  3 2014 locilka@suse.com
- Marked "runlevel" as not clonable, the functionality is there
  for importing old profiles only (bnc#873604)
- 3.1.17
* Wed Jul  2 2014 vmoravec@suse.com
- Fix failing tests
- 3.1.16
* Tue Jul  1 2014 vmoravec@suse.com
- Fix issues with ServicesManagerTarget (bnc#869656, bnc#867759,
  bnc#875098)
- 3.1.15
* Fri Jun  6 2014 locilka@suse.com
- AutoYast summary - hard-coded ERB moved to separate file
  to be able to generate translations (bnc#878606)
- Added missing textdomain (bnc#881277)
- 3.1.14
* Mon May 12 2014 vmoravec@suse.com
- Fix displaying icon twice in control centre (bnc#874124)
- 3.1.13
* Thu Apr 10 2014 vmoravec@suse.com
- Add support for legacy runlevel autoyast profile and improve
  profile specifications (bnc#865347)
- 3.1.12
* Tue Mar 18 2014 vmoravec@suse.com
- Do not crash installation with empty services list (bnc#868614)
- 3.1.11
* Mon Mar 17 2014 vmoravec@suse.com
- Do not disable services not listed in autoyast profile
  in second stage (bnc#868042)
- 3.1.10
* Fri Mar  7 2014 vmoravec@suse.com
- Respect the user preference for default target (bnc#867125)
- 3.1.9
* Fri Feb 28 2014 vmoravec@suse.com
- Reload target detection after install config change (bnc#866292)
- 3.1.8
* Wed Feb 26 2014 vmoravec@suse.com
- Select the current default target in the proposal (bnc#865357)
- 3.1.7
* Tue Feb 25 2014 vmoravec@suse.com
- Fix crashing installer if canceled target proposal (bnc#865354)
- 3.1.6
* Thu Feb 20 2014 vmoravec@suse.com
- Fix wrong target selection (bnc#864073)
- 3.1.5
* Thu Feb 20 2014 vmoravec@suse.com
- Add explicit empty default target (bnc#864073)
- 3.1.4
* Mon Feb 17 2014 jreidinger@suse.com
- fix latest fix for constant refine (bnc#864055)
- 3.1.3
* Thu Feb 13 2014 jreidinger@suse.com
- avoid constant redefine warning (BNC#861529)
- 3.1.2
* Wed Feb 12 2014 jreidinger@suse.com
- fix namespace collision for minimal installation
- 3.1.1
* Wed Feb 12 2014 vmoravec@suse.com
- main version change
- README.md update
- 3.1.0
* Tue Feb 11 2014 jreidinger@suse.com
- fix dependencies to not allow old yast2-installation
- 0.0.24
* Fri Feb  7 2014 jreidinger@suse.com
- support minimal installation (FATE#313149)
- 0.0.23
* Tue Jan  7 2014 locilka@suse.com
- Reusing already defined constant in SystemdTarget instead of
  redefining it again
- 0.0.22
* Tue Dec  3 2013 vmoravec@suse.com
- 0.0.21
- Fix installation proposal for default taret
- Do not validate new target outside of normal mode
* Thu Nov 28 2013 vmoravec@suse.com
- 0.0.20
- fix prep in spec
* Wed Nov 27 2013 vmoravec@suse.com
- 0.0.19
- use versioned tarball
* Wed Nov 27 2013 vmoravec@suse.com
- 0.0.18
- remove dependency on ruby 2.0
* Wed Nov 27 2013 vmoravec@suse.com
- fix publishing export method in SystemdService module
- 0.0.17
* Tue Nov 26 2013 vmoravec@suse.cz
- fix missing dependency on Mode module
- 0.0.16
* Fri Nov 22 2013 vmoravec@suse.com
- 0.0.15
- do not call dbus during installation for setting
  default_target
* Mon Nov 11 2013 vmoravec@suse.com
- 0.0.14
- obsoletes yast2-runlevel package
* Mon Nov 11 2013 vmoravec@suse.com
- 0.0.13
- group base target constants for better referencing from
  withing other modules and clients
* Wed Nov  6 2013 vmoravec@suse.com
- 0.0.12
- complete autoyast support
* Mon Nov  4 2013 vmoravec@suse.com
- 0.0.11
- list missing LSB services bnc#846422
* Fri Oct 25 2013 vmoravec@suse.com
- 0.0.10
- add alias services for services-manager client
- replace old tests with rspec tests
- add yast clients: target_proposal, services_proposal, target_finish
- various fixes of modules' API
* Sun Sep 15 2013 tchvatal@suse.com
- Fix the ruby dep and drop clean section as it is useless.
* Fri Sep 13 2013 vmoravec@suse.com
- 0.0.9
- Refactoring of module API
- Added tests
* Wed Jul 10 2013 locilka@suse.com
- 0.0.8
- Added full AutoYast support
- Temporarily disabled tests for openSUSE 13.1 and further
- Added dependency on ruby-bindings >= 1.2.0
* Thu Jul  4 2013 locilka@suse.com
- Dialogs and their handling split into separate file to be used
  from Autoyast
- Double click in table of services enables/disables the selected
  service
* Thu Jun 27 2013 vmoravec@suse.com
- 0.0.7
- Use updated yast2-ruby-bindings
- Adapt namespace to new yast2-ruby-bindings
* Fri Jun 21 2013 locilka@suse.com
- 0.0.6
- Added infrastructure for tests and one simple exemplary test
* Fri Jun 21 2013 locilka@suse.com
- 0.0.5
- SystemdTarget.all changed to return hash instead of array
- Using target description in UI
* Thu Jun 20 2013 locilka@suse.com
- 0.0.4
- Initial version: Services can be started and stopped, enabled
  or disabled. Default target can be set.
